==> php55-owncloud-8.2.2.tgz: share/owncloud/apps/files/l10n/bg_BG.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Липсва дисковото устройство.",
    "Storage invalid" : "Невалидно дисково устройство.",
    "Unknown error" : "Непозната грешка.",
    "Could not move %s - File with this name already exists" : "Неуспешно преместване на %s - Файл със същото име вече съществува.",
    "Could not move %s" : "Неуспешно преместване на %s.",
    "Permission denied" : "Достъпът отказан",
    "The target folder has been moved or deleted." : "Крайната папка е изтрита или преместена.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Името %s е вече в папка %s. Моля, избери друго име.",
    "Error when creating the file" : "Грешка при създаването на файлът.",
    "Error when creating the folder" : "Грешка при създаването на папката.",
    "Unable to set upload directory." : "Неуспешно задаване на директория за качване.",
    "Invalid Token" : "Невалиеден токен.",
    "No file was uploaded. Unknown error" : "Неуспешно качвачване на файл. Непозната грешка.",
    "There is no error, the file uploaded with success" : "Файлът е качен успешно.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Файлът, който се опитваше да качиш надвишава зададения upload_max_filesize размер в php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Файлът, който се опитваш да качиш надвишава стойностите в MAX_FILE_SIZE в HTML формата.",
    "The uploaded file was only partially uploaded" : "Файлът е качен частично.",
    "No file was uploaded" : "Неуспешно качване.",
    "Missing a temporary folder" : "Липсва временна папка.",
    "Failed to write to disk" : "Възникна проблем при запис на диска.",
    "Not enough storage available" : "Недостатъчно място.",
    "Upload failed. Could not find uploaded file" : "Неуспешно качване. Не бе открит качения файл.",
    "Upload failed. Could not get file info." : "Неуспешно качване. Не се получи информация за файла.",
    "Invalid directory." : "Невалидна директория.",
    "Files" : "Файлове",
    "All files" : "Всички файлове",
    "Favorites" : "Любими",
    "Home" : "Домашен",
    "Close" : "Затвори",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или е с размер от 0 байта.",
    "Total file size {size1} exceeds upload limit {size2}" : "Общия размер {size1} надминава лимита за качване {size2}.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място, ти се опитваш да качиш {size1}, но са останали само {size2}.",
    "Upload cancelled." : "Качването е прекъснато.",
    "Could not get result from server." : "Не се получи резултат от сървърът.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Извършва се качване на файлове. Затварянето на тази страница ще прекъсне качването.",
    "Actions" : "Действия",
    "Download" : "Изтегли",
    "Rename" : "Преименуване",
    "Delete" : "Изтрий",
    "Details" : "Подробности",
    "Select" : "Избери",
    "Pending" : "Чакащо",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "Error moving file." : "Грешка при местенето на файла.",
    "Error moving file" : "Грешка при преместването на файла.",
    "Error" : "Грешка",
    "{new_name} already exists" : "{new_name} вече съществува.",
    "Could not rename file" : "Неуспешно преименуване на файла.",
    "Could not create file" : "Несупешно създаване на файла.",
    "Could not create folder" : "Неуспешно създаване на папка.",
    "Error deleting file." : "Грешка при изтриването на файла.",
    "No entries in this folder match '{filter}'" : "Нищо в тази папка не отговаря на '{filter}'",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла."],
    "New" : "Създай",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "Your storage is full, files can not be updated or synced anymore!" : "Заделеното място е запълнено, повече файлове не могат да бъдат синхронизирани или опреснени!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Заделеното място е почити запълнено ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
    "Favorited" : "Отбелязано в любими",
    "Favorite" : "Любими",
    "Upload" : "Качване",
    "Text file" : "Текстов файл",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "An error occurred while trying to update the tags" : "Настъпи грешка при опита за промяна на бележките",
    "A new file or folder has been <strong>created</strong>" : "Нов файл или папка беше <strong>създаден/а</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл или папка беше <strong>променен/а</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Файл или папка беше <strong>изтрит/а</strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл или папка беше <strong>възстановен/а</strong>",
    "You created %1$s" : "Вие създадохте %1$s.",
    "%2$s created %1$s" : "%2$s създаде %1$s.",
    "%1$s was created in a public folder" : "%1$s е създаден в публична папка",
    "You changed %1$s" : "Вие променихте %1$s.",
    "%2$s changed %1$s" : "%2$s промени %1$s.",
    "You deleted %1$s" : "Вие изтрихте %1$s.",
    "%2$s deleted %1$s" : "%2$s изтри %1$s.",
    "You restored %1$s" : "Вие възстановихте %1$s",
    "%2$s restored %1$s" : "%2$s възстанови %1$s",
    "%s could not be renamed as it has been deleted" : "%s не може да бъде преименуван, защото е вече изтрит",
    "%s could not be renamed" : "%s не може да бъде преименуван.",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "File handling" : "Операция с файла",
    "Maximum upload size" : "Максимален размер",
    "max. possible: " : "максимално:",
    "Save" : "Запис",
    "Can not be edited from here due to insufficient permissions." : "Не може да бъде редактиран от тук, поради липса на права",
    "Settings" : "Настройки",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Използвай този адрес, за да получиш <a href=\"%s\" target=\"_blank\">достъп до своите файлове чрез WebDAV</a>.",
    "Cancel upload" : "Отказване на качването",
    "No files in here" : "Тук няма файлове",
    "Upload some content or sync with your devices!" : "Качи съдържание или синхронизирай с твоите устройства!",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване.",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитваш да качиш са по-големи от позволеното на този сървър.",
    "Files are being scanned, please wait." : "Файловете се сканирват, изчакайте.",
    "Currently scanning" : "В момента се търси",
    "No favorites" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които отбелязваш като любими ще се показват тук"
},
"nplurals=2; plural=(n != 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/files/l10n/bg_BG.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Липсва дисковото устройство.",
    "Storage invalid" : "Невалидно дисково устройство.",
    "Unknown error" : "Непозната грешка.",
    "Unable to set upload directory." : "Неуспешно задаване на директория за качване.",
    "Invalid Token" : "Невалиеден токен.",
    "No file was uploaded. Unknown error" : "Неуспешно качвачване на файл. Непозната грешка.",
    "There is no error, the file uploaded with success" : "Файлът е качен успешно.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Файлът, който се опитваше да качиш надвишава зададения upload_max_filesize размер в php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Файлът, който се опитваш да качиш надвишава стойностите в MAX_FILE_SIZE в HTML формата.",
    "The uploaded file was only partially uploaded" : "Файлът е качен частично.",
    "No file was uploaded" : "Неуспешно качване.",
    "Missing a temporary folder" : "Липсва временна папка.",
    "Failed to write to disk" : "Възникна проблем при запис на диска.",
    "Not enough storage available" : "Недостатъчно място.",
    "The target folder has been moved or deleted." : "Крайната папка е изтрита или преместена.",
    "Upload failed. Could not find uploaded file" : "Неуспешно качване. Не бе открит качения файл.",
    "Upload failed. Could not get file info." : "Неуспешно качване. Не се получи информация за файла.",
    "Invalid directory." : "Невалидна директория.",
    "Files" : "Файлове",
    "All files" : "Всички файлове",
    "Favorites" : "Любими",
    "Home" : "Домашен",
    "Close" : "Затвори",
    "Upload cancelled." : "Качването е прекъснато.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или е с размер от 0 байта.",
    "Total file size {size1} exceeds upload limit {size2}" : "Общия размер {size1} надминава лимита за качване {size2}.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място, ти се опитваш да качиш {size1}, но са останали само {size2}.",
    "Could not get result from server." : "Не се получи резултат от сървърът.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Извършва се качване на файлове. Затварянето на тази страница ще прекъсне качването.",
    "Actions" : "Действия",
    "Download" : "Изтегли",
    "Rename" : "Преименуване",
    "Delete" : "Изтрий",
    "Disconnect storage" : "Извади дисковото устройство.",
    "Unshare" : "Премахване на споделяне",
    "Details" : "Подробности",
    "Select" : "Избери",
    "Pending" : "Чакащо",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "No entries in this folder match '{filter}'" : "Нищо в тази папка не отговаря на '{filter}'",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла."],
    "New" : "Създай",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "Your storage is full, files can not be updated or synced anymore!" : "Заделеното място е запълнено, повече файлове не могат да бъдат синхронизирани или опреснени!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Заделеното място е почити запълнено ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
    "Favorited" : "Отбелязано в любими",
    "Favorite" : "Любими",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "Upload" : "Качване",
    "An error occurred while trying to update the tags" : "Настъпи грешка при опита за промяна на бележките",
    "A new file or folder has been <strong>created</strong>" : "Нов файл или папка беше <strong>създаден/а</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл или папка беше <strong>променен/а</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Файл или папка беше <strong>изтрит/а</strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл или папка беше <strong>възстановен/а</strong>",
    "You created %1$s" : "Вие създадохте %1$s.",
    "%2$s created %1$s" : "%2$s създаде %1$s.",
    "%1$s was created in a public folder" : "%1$s е създаден в публична папка",
    "You changed %1$s" : "Вие променихте %1$s.",
    "%2$s changed %1$s" : "%2$s промени %1$s.",
    "You deleted %1$s" : "Вие изтрихте %1$s.",
    "%2$s deleted %1$s" : "%2$s изтри %1$s.",
    "You restored %1$s" : "Вие възстановихте %1$s",
    "%2$s restored %1$s" : "%2$s възстанови %1$s",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "File handling" : "Операция с файла",
    "Maximum upload size" : "Максимален размер",
    "max. possible: " : "максимално:",
    "Save" : "Запис",
    "Settings" : "Настройки",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Използвай този адрес, за да получиш <a href=\"%s\" target=\"_blank\">достъп до своите файлове чрез WebDAV</a>.",
    "Cancel upload" : "Отказване на качването",
    "No files in here" : "Тук няма файлове",
    "Upload some content or sync with your devices!" : "Качи съдържание или синхронизирай с твоите устройства!",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване.",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитваш да качиш са по-големи от позволеното на този сървър.",
    "No favorites" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които отбелязваш като любими ще се показват тук",
    "Text file" : "Текстов файл"
},
"nplurals=2; plural=(n != 1);");
